@@ -51,7 +51,7 @@ public:
    * The <i>currentSegmentArea</i> specifies the clipping area.
    */
   virtual void startSegment(int currentXSegment, int currentYSegment,
-			    const WRectF& currentSegmentArea);
+                            const WRectF& currentSegmentArea);
 
   /*! \brief End handling a particular segment.
    *
@@ -67,7 +67,7 @@ public:
    * series is in the <i>currentBarGroup</i>'th group.
    */
   virtual bool startSeries(const WDataSeries& series, double groupWidth,
-			   int numBarGroups, int currentBarGroup);
+                           int numBarGroups, int currentBarGroup);
 
   /*! \brief End iterating a particular series.
    */
@@ -85,8 +85,8 @@ public:
    * stacked.
    */
   virtual void newValue(const WDataSeries& series, double x, double y,
-			double stackY, int xRow, int xColumn,
-			int yRow, int yColumn);
+                        double stackY, int xRow, int xColumn,
+                        int yRow, int yColumn);
 
   /*! \brief Returns the current X segment.
    */
@@ -97,14 +97,14 @@ public:
   int currentYSegment() const { return currentYSegment_; }
 
   static void setPenColor(WPen& pen, const WDataSeries& series,
-		   int xRow, int xColumn,
-		   int yRow, int yColumn,
-		   ItemDataRole colorRole);
+                   int xRow, int xColumn,
+                   int yRow, int yColumn,
+                   ItemDataRole colorRole);
 
   static void setBrushColor(WBrush& brush, const WDataSeries& series,
-		     int xRow, int xColumn,
-		     int yRow, int yColumn,
-		     ItemDataRole colorRole);
+                     int xRow, int xColumn,
+                     int yRow, int yColumn,
+                     ItemDataRole colorRole);
 
 private:
   int currentXSegment_, currentYSegment_;
@@ -360,7 +360,7 @@ typedef std::map<WFlags<KeyboardModifier>, InteractiveAction> WheelActions;
  * The cartesian chart has support for dual Y axes. Each data series may
  * be bound to one of the two Y axes. By default, only the first Y axis
  * is displayed. To show the second Y axis you will need to call:
- * 
+ *
  * \if cpp
  * \code
  * chart->axis(Axis::Y2).setVisible(true);
@@ -386,14 +386,14 @@ typedef std::map<WFlags<KeyboardModifier>, InteractiveAction> WheelActions;
  * %WCartesianChart has several features that allow interaction with the
  * chart without server roundtrips. These features include zoom, pan,
  * crosshair and follow curve functionality.
- * 
+ *
  * \note Client side interaction is only available if the chart is drawn
  *       on an HTML canvas. This is the default rendering method on
  *       modern browsers, see WPaintedWidget::setPreferredMethod()
  *
  * \note Some features are currently not supported in interactive mode:
  *       - Axes set at AxisValue::Zero position will not always be drawn correctly.
- *	     They may be clipped off outside of the chart area, and when
+ *             They may be clipped off outside of the chart area, and when
  *         zooming, the axis ticks will change size.
  *       - WAxis::setBreak() is incompatible with interactive mode
  *
@@ -462,7 +462,7 @@ public:
   /*! \brief Returns the chart orientation.
    *
    * \sa setOrientation()
-   */  
+   */
   Orientation orientation() const { return orientation_; }
 
   /*! \brief Sets the the model column for the X series.
@@ -576,6 +576,18 @@ public:
    */
   void setAxis(std::unique_ptr<WAxis> waxis, Axis axis);
 
+  /*! \brief Returns a vector of all X axes associated with this chart.
+   *
+   * This defaults to a vector of one axis.
+   */
+  std::vector<WAxis*> xAxes();
+
+  /*! \brief Returns a vector of all X axes associated with this chart.
+   *
+   * This defaults to a vector of one axis.
+   */
+  std::vector<const WAxis*> xAxes() const;
+
   /*! \brief Returns a vector of all Y axes associated with this chart.
    *
    * This defaults to a vector of two axes: the Y1 and Y2 axes. Y1 will
@@ -590,10 +602,54 @@ public:
    */
   std::vector<const WAxis*> yAxes() const;
 
+  /*! \brief Returns the number of X axes associated with this chart.
+   */
+  int xAxisCount() const;
+
   /*! \brief Returns the number of Y axes associated with this chart.
    */
   int yAxisCount() const;
 
+  /*! \brief Retrieves the X axis at index i
+   *
+   * The following expression is always true:
+   *
+   * \if cpp
+   * \code
+   * &axis(X) == &xAxis(0)
+   * \endcode
+   * \endif
+   *
+   * \if java
+   * \code
+   * getAxis(Axis.XAxis) == getXAxis(0)
+   * \endcode
+   * \endif
+   *
+   * \note Precondition: 0 <= i < xAxisCount()
+   */
+  WAxis &xAxis(int i);
+
+  /*! \brief Retrieves the X axis at index i
+   *
+   * The following expression is always true:
+   *
+   * \if cpp
+   * \code
+   * &axis(X) == &xAxis(0)
+   * \endcode
+   * \endif
+   *
+   * \if java
+   * \code
+   * getAxis(Axis.XAxis) == getXAxis(0)
+   * \endcode
+   * \endif
+   *
+   * \note Precondition: 0 <= i < xAxisCount()
+   */
+  const WAxis &xAxis(int i) const;
+
   /*! \brief Retrieves the Y axis at index i
    *
    * The following expressions are always true:
@@ -638,6 +694,18 @@ public:
    */
   const WAxis &yAxis(int i) const;
 
+  /*! \brief Adds a X axis to this chart.
+   *
+   * The first extra axis will have index 1, the next index 2,...
+   *
+   * Returns the index of the added axis.
+   *
+   * \note This transfers ownership of the given WAxis to this chart.
+   *
+   * \note Precondition: waxis is not null
+   */
+  int addXAxis(std::unique_ptr<WAxis> waxis);
+
   /*! \brief Adds a Y axis to this chart.
    *
    * The first extra axis will have index 2, the next index 3,...
@@ -650,6 +718,18 @@ public:
    */
   int addYAxis(std::unique_ptr<WAxis> waxis);
 
+  /*! \brief Removes the X axis with the given id.
+   *
+   * The indices of the axes with an id higher than
+   * xAxisId will be decremented.
+   *
+   * Any WDataSeries associated with the removed axis
+   * are also removed.
+   *
+   * \note Precondition: 0 <= xAxisId < xAxisCount()
+   */
+  std::unique_ptr<WAxis> removeXAxis(int xAxisId);
+
   /*! \brief Removes the Y axis with the given id.
    *
    * The indices of the axes with an id higher than
@@ -662,6 +742,14 @@ public:
    */
   std::unique_ptr<WAxis> removeYAxis(int yAxisId);
 
+  /*! \brief Clears all X axes.
+   *
+   * The effect is the same as repeatedly using removeYAxis()
+   * until are axes are removed, i.e. any WDataSeries will
+   * also be removed.
+   */
+  void clearXAxes();
+
   /*! \brief Clears all Y axes.
    *
    * The effect is the same as repeatedly using removeYAxis()
@@ -740,7 +828,7 @@ public:
    * \sa WDataSeries::setLegendEnabled()
    */
   void setLegendLocation(LegendLocation location, Side side,
-			 AlignmentFlag alignment);
+                         AlignmentFlag alignment);
 
   /*! \brief Configures the legend decoration.
    *
@@ -754,7 +842,7 @@ public:
    * \sa setLegendEnabled()
    */
   void setLegendStyle(const WFont& font, const WPen& border,
-		      const WBrush& background);
+                      const WBrush& background);
 
   /*! \brief Returns the legend location.
    *
@@ -817,7 +905,7 @@ public:
    * \sa setAutoLayoutEnabled()
    */
   void setLegendColumns(int columns, const WLength& width);
-  
+
   virtual void paint(WPainter& painter, const WRectF& rectangle = WRectF())
     const override;
 
@@ -845,7 +933,7 @@ public:
    * \sa renderLegendItem()
    */
   virtual void renderLegendIcon(WPainter& painter, const WPointF& pos,
-				const WDataSeries& series) const;
+                                const WDataSeries& series) const;
 
   /*! \brief Renders the legend item for a given data series.
    *
@@ -862,7 +950,7 @@ public:
    * \sa setLegendEnabled()
    */
   virtual void renderLegendItem(WPainter& painter, const WPointF& pos,
-				const WDataSeries& series) const;
+                                const WDataSeries& series) const;
 
   /*! \brief Maps from device coordinates to model coordinates.
    *
@@ -879,7 +967,7 @@ public:
    * \sa mapToDevice()
    */
   WPointF mapFromDevice(const WPointF& point,
-			Axis ordinateAxis = Axis::Ordinate) const;
+                        Axis ordinateAxis = Axis::Ordinate) const;
 
   /*! \brief Maps from device coordinates to model coordinates.
    *
@@ -915,7 +1003,25 @@ public:
    * \sa mapToDeviceWithoutTransform()
    */
   WPointF mapFromDeviceWithoutTransform(const WPointF& point,
-			Axis ordinateAxis = Axis::Ordinate) const;
+                        Axis ordinateAxis = Axis::Ordinate) const;
+
+  /*! \brief Maps from device coordinates to model coordinates.
+   *
+   * Maps a position in the chart back to model coordinates.
+   *
+   * This uses the axis dimensions that are based on the latest chart
+   * rendering. If you have not yet rendered the chart, or wish that
+   * the mapping already reflects model changes since the last rendering,
+   * you should call initLayout() first.
+   *
+   * If the chart is interactive, mapFromDevice will correctly take the current
+   * zoom range into account.
+   *
+   * \sa mapToDevice()
+   */
+  WPointF mapFromDevice(const WPointF &point,
+                        const WAxis &xAxis,
+                        const WAxis &yAxis) const;
 
   /*! \brief Maps from device coordinates to model coordinates, ignoring the current zoom range
    *
@@ -936,6 +1042,26 @@ public:
   WPointF mapFromDeviceWithoutTransform(const WPointF& point,
                         int ordinateAxis) const;
 
+  /*! \brief Maps from device coordinates to model coordinates, ignoring the current zoom range
+   *
+   * Maps a position in the chart back to model coordinates, as if the
+   * chart was not zoomed in (nor panned).
+   *
+   * This uses the axis dimensions that are based on the latest chart
+   * rendering. If you have not yet rendered the chart, or wish that
+   * the mapping already reflects model changes since the last rendering,
+   * you should call initLayout() first.
+   *
+   * This function will not take the current zoom range into
+   * account. The mapping will be performed as if zoomRangeTransform()
+   * is the identity transform.
+   *
+   * \sa mapToDeviceWithoutTransform()
+   */
+  WPointF mapFromDeviceWithoutTransform(const WPointF& point,
+                                        const WAxis &xAxis,
+                                        const WAxis &yAxis) const;
+
   /*! \brief Maps model values onto chart coordinates.
    *
    * This returns the chart device coordinates for a (x,y) pair of model
@@ -957,8 +1083,8 @@ public:
    * \sa mapFromDevice()
    */
   WPointF mapToDevice(const cpp17::any& xValue, const cpp17::any& yValue,
-		      Axis axis = Axis::Ordinate, int xSegment = 0,
-		      int ySegment = 0) const;
+                      Axis axis = Axis::Ordinate, int xSegment = 0,
+                      int ySegment = 0) const;
 
   /*! \brief Maps model values onto chart coordinates.
    *
@@ -984,6 +1110,30 @@ public:
                       int yAxis, int xSegment = 0,
                       int ySegment = 0) const;
 
+  /*! \brief Maps model values onto chart coordinates.
+   *
+   * This returns the chart device coordinates for a (x,y) pair of model
+   * values.
+   *
+   * This uses the axis dimensions that are based on the latest chart
+   * rendering. If you have not yet rendered the chart, or wish that
+   * the mapping already reflects model changes since the last rendering,
+   * you should call initLayout() first.
+   *
+   * The \p xSegment and \p ySegment arguments are relevant only when
+   * the corresponding axis is broken using WAxis::setBreak(). Then,
+   * its possible values may be 0 (below the break) or 1 (above the
+   * break).
+   *
+   * If the chart is interactive, mapToDevice will correctly take the current
+   * zoom range into account.
+   *
+   * \sa mapFromDevice()
+   */
+  WPointF mapToDevice(const cpp17::any& xValue, const cpp17::any& yValue,
+                      const WAxis &xAxis, const WAxis &yAxis,
+                      int xSegment = 0, int ySegment = 0) const;
+
   /*! \brief Maps model values onto chart coordinates, ignoring the current zoom range
    *
    * This returns the chart device coordinates for a (x,y) pair of model
@@ -1006,8 +1156,8 @@ public:
    * \sa mapFromDeviceWithoutTransform()
    */
   WPointF mapToDeviceWithoutTransform(const cpp17::any& xValue, const cpp17::any& yValue,
-		      Axis axis = Axis::Ordinate, int xSegment = 0,
-		      int ySegment = 0) const;
+                      Axis axis = Axis::Ordinate, int xSegment = 0,
+                      int ySegment = 0) const;
 
   /*! \brief Maps model values onto chart coordinates, ignoring the current zoom range
    *
@@ -1034,6 +1184,31 @@ public:
                       int yAxis, int xSegment = 0,
                       int ySegment = 0) const;
 
+  /*! \brief Maps model values onto chart coordinates, ignoring the current zoom range
+   *
+   * This returns the chart device coordinates for a (x,y) pair of model
+   * values.
+   *
+   * This uses the axis dimensions that are based on the latest chart
+   * rendering. If you have not yet rendered the chart, or wish that
+   * the mapping already reflects model changes since the last rendering,
+   * you should call initLayout() first.
+   *
+   * The \p xSegment and \p ySegment arguments are relevant only when
+   * the corresponding axis is broken using WAxis::setBreak(). Then,
+   * its possible values may be 0 (below the break) or 1 (above the
+   * break).
+   *
+   * This function will not take the current zoom range into
+   * account.The mapping will be performed as if zoomRangeTransform()
+   * is the identity transform.
+   *
+   * \sa mapFromDeviceWithoutTransform()
+   */
+  WPointF mapToDeviceWithoutTransform(const cpp17::any& xValue, const cpp17::any& yValue,
+                                      const WAxis &xAxis, const WAxis &yAxis,
+                                      int xSegment = 0, int ySegment = 0) const;
+
   /*! \brief Initializes the chart layout.
    *
    * The mapping between model and device coordinates is only
@@ -1047,11 +1222,11 @@ public:
    * area is assumed.
    */
   bool initLayout(const WRectF& rectangle = WRectF(),
-		  WPaintDevice *device = nullptr) const;
+                  WPaintDevice *device = nullptr) const;
 
   /*! \brief Creates a widget which renders the a legend item.
-   * 
-   * The legend item widget will contain a text and a WPaintedWidget 
+   *
+   * The legend item widget will contain a text and a WPaintedWidget
    * which draws the series' symbol.
    */
   std::unique_ptr<WWidget> createLegendItemWidget(int index);
@@ -1065,8 +1240,8 @@ public:
    *       at the data point is not empty.
    */
   virtual void addDataPointArea(const WDataSeries& series,
-				int xRow, int xColumn,
-				std::unique_ptr<WAbstractArea> area);
+                                int xRow, int xColumn,
+                                std::unique_ptr<WAbstractArea> area);
 
   /*! \brief Sets the padding between the chart area and the axes.
    *
@@ -1127,14 +1302,14 @@ public:
    *
    * These methods allow to activate the client side interactive features of
    * a %WCartesianChart.
-   * 
+   *
    * \note Client side interaction is only available if the chart is drawn
    *       on an HTML canvas. This is the default rendering method on
    *       modern browsers, see WPaintedWidget::setPreferredMethod()
    *
    * \note Some features are currently not supported in interactive mode:
    *       - Axes set at AxisValue::Zero position will not always be drawn correctly.
-   *	     They may be clipped off outside of the chart area, and when
+   *             They may be clipped off outside of the chart area, and when
    *         zooming, the axis ticks will change size.
    *       - WAxis::setBreak() is incompatible with interactive mode
    */
@@ -1188,7 +1363,7 @@ public:
    * \sa panEnabled()
    */
   void setPanEnabled(bool pan = true);
-  
+
   /*! \brief Returns whether pan is enabled.
    *
    * \sa setPanEnabled()
@@ -1228,6 +1403,16 @@ public:
    */
   const WColor& crosshairColor() const { return crosshairColor_; }
 
+  /*! \brief Sets the X axis to use for the crosshair.
+   *
+   * Defaults to 0 (first X axis)
+   */
+  void setCrosshairXAxis(int xAxis);
+
+  /*! \brief Returns the X axis to use for the crosshair.
+   */
+  int crosshairXAxis() const { return crosshairXAxis_; }
+
   /*! \brief Sets the Y axis to use for the crosshair.
    *
    * Defaults to 0 (first Y axis)
@@ -1306,7 +1491,7 @@ public:
   void setRubberBandEffectEnabled(bool rubberBand = true);
 
   /*! \brief Checks whether the rubberband effect is enabled.
-   * 
+   *
    * \see setRubberBandEffectEnabled()
    */
   bool rubberBandEffectEnabled() const;
@@ -1322,7 +1507,7 @@ public:
    * \sa setWheelActions()
    */
   WheelActions wheelActions() const { return wheelActions_; }
-  
+
   /*! \brief Enables or disables soft label clipping on all axes.
    *
    * \sa WAxis::setSoftLabelClipping()
@@ -1452,7 +1637,7 @@ public:
   //!@}
 
   void iterateSeries(SeriesIterator *iterator,
-		     WPainter *painter, bool reverseStacked = false, bool extremesOnly = false) const;
+                     WPainter *painter, bool reverseStacked = false, bool extremesOnly = false) const;
 
   // For use in WAxisSliderWidget
   void addAxisSliderWidget(WAxisSliderWidget *slider);
@@ -1484,8 +1669,8 @@ private:
     WJavaScriptHandle<WPen> gridPen;
 
     PenAssignment(const WJavaScriptHandle<WPen>& pen,
-		  const WJavaScriptHandle<WPen>& textPen,
-		  const WJavaScriptHandle<WPen>& gridPen)
+                  const WJavaScriptHandle<WPen>& textPen,
+                  const WJavaScriptHandle<WPen>& gridPen)
       : pen(pen), textPen(textPen), gridPen(gridPen)
     { }
   };
@@ -1513,7 +1698,7 @@ private:
   int XSeriesColumn_;
   ChartType type_;
   std::vector<std::unique_ptr<WDataSeries> > series_;
-  AxisStruct xAxis_;
+  std::vector<AxisStruct> xAxes_;
   std::vector<AxisStruct> yAxes_;
   double barMargin_;
   WLegend legend_;
@@ -1532,6 +1717,7 @@ private:
   bool rubberBandEnabled_;
   bool crosshairEnabled_;
   WColor crosshairColor_;
+  int crosshairXAxis_;
   int crosshairYAxis_;
   bool seriesSelectionEnabled_;
   const WDataSeries *selectedSeries_;
@@ -1564,10 +1750,10 @@ private:
   struct BarTooltip {
     BarTooltip(const WDataSeries &series, int xRow, int xColumn, int yRow, int yColumn)
       : series(&series),
-	xRow(xRow),
-	xColumn(xColumn),
-	yRow(yRow),
-	yColumn(yColumn)
+        xRow(xRow),
+        xColumn(xColumn),
+        yRow(yRow),
+        yColumn(yColumn)
     { }
 
     double xs[4];
@@ -1634,19 +1820,48 @@ protected:
    *
    * The result needs further transformation using hv() to painter
    * coordinates.
+   *
+   * \if cpp
+   *
+   * The default implementation is:
+   *
+   * \code
+   * return map(xValue, yValue, yAxis == Y1Axis ? 0 : 1, currentXSegment, currentYSegment);
+   * \endcode
+   *
+   * \endif
    */
-  virtual WPointF map(double xValue, double yValue, 
-		      Axis yAxis = Axis::Ordinate,
-		      int currentXSegment = 0, int currentYSegment = 0) const;
+  virtual WPointF map(double xValue, double yValue,
+                      Axis yAxis = Axis::Ordinate,
+                      int currentXSegment = 0, int currentYSegment = 0) const;
+
+  /*! \brief Map (x, y) value pair to chart coordinates coordinates.
+   *
+   * The result needs further transformation using hv() to painter
+   * coordinates.
+   *
+   * \if cpp
+   *
+   * The default implementation is:
+   *
+   * \code
+   * return map(xValue, yValue, xAxis(0), this->yAxis(yAxis), currentXSegment, currentYSegment);
+   * \endcode
+   *
+   * \endif
+   */
+  virtual WPointF map(double xValue, double yValue, int yAxis,
+                      int currentXSegment = 0, int currentYSegment = 0)
+    const;
 
   /*! \brief Map (x, y) value pair to chart coordinates coordinates.
    *
    * The result needs further transformation using hv() to painter
    * coordinates.
    */
-  virtual WPointF map(double xValue, double yValue, int yAxis,
-                      int currentXSegment = 0, int currentYSegment = 0)
-    const;
+  virtual WPointF map(double xValue, double yValue,
+                      const WAxis &xAxis, const WAxis &yAxis,
+                      int currentXSegment = 0, int currentYSegment = 0) const;
 
   /*! \brief Utility function for rendering text.
    *
@@ -1659,9 +1874,9 @@ protected:
    * horizontal text, regardless of the chart orientation.
    */
   virtual void renderLabel(WPainter& painter, const WString& text,
-			   const WPointF& pos,
-			   WFlags<AlignmentFlag> flags, double angle,
-			   int margin) const;
+                           const WPointF& pos,
+                           WFlags<AlignmentFlag> flags, double angle,
+                           int margin) const;
 
   /*! \brief Conversion between chart and painter coordinates.
    *
@@ -1692,6 +1907,14 @@ protected:
    */
   WRectF chartSegmentArea(const WAxis& yAxis, int xSegment, int ySegment) const;
 
+  /*! \brief Returns the segment area for a combination of X and Y
+   *         segments.
+   *
+   * This segment area is used for clipping when rendering in a
+   * particular segment.
+   */
+  WRectF chartSegmentArea(const WAxis& xAxis, const WAxis& yAxis, int xSegment, int ySegment) const;
+
   /*! \brief Calculates the chart area.
    *
    * This calculates the chartArea(), which is the rectangle (in chart
@@ -1725,7 +1948,7 @@ protected:
    * \sa render()
    */
   virtual void renderAxes(WPainter& painter,
-			  WFlags<AxisProperty> properties) const;
+                          WFlags<AxisProperty> properties) const;
 
   /*! \brief Renders the border of the chart area.
    *
@@ -1758,7 +1981,7 @@ protected:
    * \sa renderAxes()
    */
   virtual void renderAxis(WPainter& painter, const WAxis& axis,
-			  WFlags<AxisProperty> properties) const;
+                          WFlags<AxisProperty> properties) const;
 
   /*! \brief Renders grid lines along the ticks of the given axis.
    *
@@ -1811,15 +2034,32 @@ protected:
    */
   WTransform zoomRangeTransform(int yAxis = 0) const;
 
+  /*! \brief Returns the current zoom range transform.
+   *
+   * This transform maps device coordinates from the fully zoomed out position
+   * to the current zoom range.
+   *
+   * This transform is a \link WTransform::isJavaScriptBound()
+   * JavaScript bound\endlink transform if this chart is
+   * interactive. Otherwise, this transform is just the identity
+   * transform.
+   *
+   * \sa setZoomEnabled()
+   * \sa setPanEnabled
+   * \sa WAxis::setZoomRange()
+   */
+  WTransform zoomRangeTransform(const WAxis &xAxis, const WAxis &yAxis) const;
+
 private:
   int calcNumBarGroups() const;
-  std::vector<const WAxis*> collectYAxesAtLocation(AxisValue side) const;
+  std::vector<const WAxis*> collectAxesAtLocation(Axis axis, AxisValue side) const;
   int seriesIndexOf(int modelColumn) const;
   int seriesIndexOf(const WDataSeries &series) const;
+  bool hasInwardsXAxisOnMinimumSide() const;
   bool hasInwardsYAxisOnMaximumSide() const;
   void clearPens();
-  void clearPensForAxis(Axis axis, int yAxis);
-  void createPensForAxis(Axis axis, int yAxis);
+  void clearPensForAxis(Axis axis, int axisId);
+  void createPensForAxis(Axis axis, int axisId);
   std::string cObjJsRef() const; // WCartesianChart JS object
   void assignJSHandlesForAllSeries();
   void freeJSHandlesForAllSeries();
@@ -1830,7 +2070,7 @@ private:
   void freeJSTransformsForSeries(const WDataSeries &series);
   void freeAllJSTransforms();
   void updateJSPens(WStringStream& js) const;
-  void updateJSPensForAxis(WStringStream& js, Axis axis, int yAxis) const;
+  void updateJSPensForAxis(WStringStream& js, Axis axis, int axisId) const;
   void updateJSConfig(const std::string &key, cpp17::any value);
   WPainterPath pathForSeries(const WDataSeries &series) const; // For use in WAxisSliderWidget
   WTransform zoomRangeTransform(const WTransform &xTransform, const WTransform &yTransform) const;
@@ -1838,7 +2078,7 @@ private:
   WTransform curveTransform(const WDataSeries &series) const;
   void setZoomAndPan();
   void addAreaMask();
-  void xTransformChanged();
+  void xTransformChanged(int xAxis);
   void yTransformChanged(int yAxis);
   void jsSeriesSelected(double x, double y);
   void loadTooltip(double x, double y);
@@ -1857,10 +2097,10 @@ private:
   class IconWidget : public WPaintedWidget {
   public:
     IconWidget(WCartesianChart *chart, int index);
-    
+
   protected:
     virtual void paintEvent(WPaintDevice *paintDevice) override;
-    
+
   private:
     WCartesianChart* chart_;
     int index_;
